@@ -32,7 +32,6 @@ class _ContinuumDataset(abc.ABC):
                 " It must be a member of the enum TaskType."
             )
 
-
         # Initialization of the default properties
         if self.data_type == TaskType.SEGMENTATION:
             self._trsf = [transforms_seg.ToTensor()]
@@ -49,11 +48,11 @@ class _ContinuumDataset(abc.ABC):
         pass
 
     def slice(
-        self,
-        keep_classes: Optional[List[int]] = None,
-        discard_classes: Optional[List[int]] = None,
-        keep_tasks: Optional[List[int]] = None,
-        discard_tasks: Optional[List[int]] = None
+            self,
+            keep_classes: Optional[List[int]] = None,
+            discard_classes: Optional[List[int]] = None,
+            keep_tasks: Optional[List[int]] = None,
+            discard_tasks: Optional[List[int]] = None
     ):
         """Slice dataset to keep/discard some classes/task-ids.
 
@@ -89,6 +88,10 @@ class _ContinuumDataset(abc.ABC):
 
         return sliced_dataset
 
+    @property
+    def nb_classes(self) -> List[int]:
+        return None
+
     @property
     def class_order(self) -> Union[None, List[int]]:
         return None
@@ -243,10 +246,15 @@ class InMemoryDataset(_ContinuumDataset):
             raise ValueError(f"Number of datapoints ({len(x)}) != number of task ids ({len(t)})!")
 
         self.data = (x, y, t)
+        self._nb_classes = len(np.unique(y))
 
     def get_data(self) -> Tuple[np.ndarray, np.ndarray, np.ndarray]:
         return self.data
 
+    @property
+    def nb_classes(self) -> List[int]:
+        return self._nb_classes
+
     @property
     def data_type(self) -> TaskType:
         return self._data_type
@@ -258,6 +266,7 @@ class InMemoryDataset(_ContinuumDataset):
 
 class H5Dataset(_ContinuumDataset):
     """Continuum dataset for in-memory data with h5 file.
+    This class either creates a h5 dataset or reload an existing one.
 
     :param x_train: Numpy array of images or paths to images for the train set.
     :param y_train: Targets for the train set.
@@ -267,39 +276,69 @@ class H5Dataset(_ContinuumDataset):
 
     def __init__(
             self,
-            x: np.ndarray,
-            y: np.ndarray,
+            x: np.ndarray = None,
+            y: np.ndarray = None,
             t: Union[None, np.ndarray] = None,
             data_path: str = "h5_dataset.h5",
             train: bool = True,
             download: bool = True,
     ):
+        self._data_type = TaskType.H5
         super().__init__(data_path=None, train=train, download=download)
+
+        if x is None:
+            # Load an existing h5_dataset
+            self._check_existing_file(data_path)
+        else:
+            if len(x) != len(y):
+                raise ValueError(f"Number of datapoints ({len(x)}) != number of labels ({len(y)})!")
+            self.no_task_index = False
+            if t is None:
+                self.no_task_index = True
+            else:
+                if len(t) != len(x):
+                    raise ValueError(f"Number of datapoints ({len(x)}) != number of task ids ({len(t)})!")
+
         self.data_path = data_path
 
-        if len(x) != len(y):
-            raise ValueError(f"Number of datapoints ({len(x)}) != number of labels ({len(y)})!")
-
-        self.no_task_index = False
-        if t is None:
-            self.no_task_index = True
-        else:
-            if len(t) != len(x):
-                raise ValueError(f"Number of datapoints ({len(x)}) != number of task ids ({len(t)})!")
-
-        self.create_file(x, y, t, self.data_path)
+        if x is not None:
+            self.create_file(x, y, t, self.data_path)
 
     @property
     def data_type(self) -> TaskType:
         return TaskType.H5
 
+    def __len__(self):
+        return len(self.get_class_vector())
+
+    def _check_existing_file(self, filename):
+        if not os.path.exists(filename):
+            raise IOError(f"You can not load unexisting file : {filename}")
+
+        with h5py.File(filename, 'r') as hf:
+            data_vector = hf['x'][:]
+            classes_vector = hf['y'][:]
+            if 't' in hf.keys():
+                self.no_task_index = False
+                task_index_vector = hf['t'][:]
+                if task_index_vector is None:
+                    self.no_task_index = True
+            else:
+                self.no_task_index = True
+
+            assert len(classes_vector) == len(data_vector)
+            if not self.no_task_index:
+                assert len(classes_vector) == len(task_index_vector)
+
+        self.data_path = filename
+
     def slice(
-        self,
-        new_h5_path: str,
-        keep_classes: Optional[List[int]] = None,
-        discard_classes: Optional[List[int]] = None,
-        keep_tasks: Optional[List[int]] = None,
-        discard_tasks: Optional[List[int]] = None
+            self,
+            new_h5_path: str,
+            keep_classes: Optional[List[int]] = None,
+            discard_classes: Optional[List[int]] = None,
+            keep_tasks: Optional[List[int]] = None,
+            discard_tasks: Optional[List[int]] = None
     ):
         """Slice dataset to keep/discard some classes/task-ids.
 
@@ -335,6 +374,9 @@ class H5Dataset(_ContinuumDataset):
 
     def create_file(self, x, y, t, data_path):
         """"Create and initiate h5 file with data, labels and task index (if not none)"""
+
+        assert not os.path.exists(data_path), print(f"You can not replace file : {data_path}")
+
         with h5py.File(data_path, 'w') as hf:
             hf.create_dataset('x', data=x, chunks=True, maxshape=([None] + list(x[0].shape)))
             hf.create_dataset('y', data=y, chunks=True, maxshape=([None]))
@@ -357,7 +399,7 @@ class H5Dataset(_ContinuumDataset):
                 task_indexes_value = hf['t'][index]
         return task_indexes_value
 
-    def get_classes(self):
+    def get_class_vector(self):
         """"Return the whole vector of classes"""
         classes_vector = None
         with h5py.File(self.data_path, 'r') as hf:
@@ -387,7 +429,7 @@ class H5Dataset(_ContinuumDataset):
                 hf["t"][-x.shape[0]:] = t
 
     def get_data(self) -> Tuple[np.ndarray, np.ndarray, np.ndarray]:
-        return self.data_path, self.get_classes(), self.get_task_indexes()
+        return self.data_path, self.get_class_vector(), self.get_task_indexes()
 
 
 class ImageFolderDataset(_ContinuumDataset):
@@ -413,13 +455,16 @@ class ImageFolderDataset(_ContinuumDataset):
         if data_type not in allowed_data_types:
             raise ValueError(f"Invalid data_type={data_type}, allowed={allowed_data_types}.")
 
+
     @property
     def data_type(self) -> TaskType:
         return self._data_type
 
     def get_data(self) -> Tuple[np.ndarray, np.ndarray, Union[None, np.ndarray]]:
         self.dataset = torchdata.ImageFolder(self.data_path)
-        return self._format(self.dataset.imgs)
+        x, y, t = self._format(self.dataset.imgs)
+        self.list_classes = np.unique(y)
+        return x, y, t
 
     @staticmethod
     def _format(raw_data: List[Tuple[str, int]]) -> Tuple[np.ndarray, np.ndarray, None]:
