@@ -1,5 +1,5 @@
 import os
-from typing import Tuple
+from typing import Tuple, List
 
 import pandas as pd
 import numpy as np
@@ -74,8 +74,8 @@ class CUB200(_ContinuumDataset):
         else:
             self.data = self.data[self.data.is_training_img == 0]
 
-        x = os.path.join(self.data_path, "CUB_200_2011", "images") + "/" + np.array(data["filedata_path"])
-        y = np.array(data["target"]) - 1  # Targets start at 1 by default, so shift to 0
+        x = os.path.join(self.data_path, "CUB_200_2011", "images") + "/" + np.array(self.data["filedata_path"])
+        y = np.array(self.data["target"]) - 1  # Targets start at 1 by default, so shift to 0
 
         self.dataset = [x, y, None]
 
