@@ -15,6 +15,12 @@ class ImageNet1000(ImageFolderDataset):
     Simple wrapper around ImageFolderDataset to provide a link to the download
     page.
     """
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        if self.train:
+            self.data_path = os.path.join(self.data_path, "train")
+        else:
+            self.data_path = os.path.join(self.data_path, "val")
 
     @property
     def transformations(self):
@@ -31,7 +37,6 @@ class ImageNet1000(ImageFolderDataset):
             )
         print("ImageNet already downloaded.")
 
-
 class ImageNet100(ImageNet1000):
     """Subset of ImageNet1000 made of only 100 classes.
 
@@ -101,9 +106,9 @@ class TinyImageNet200(_ContinuumDataset):
 
     def _download(self):
         path = os.path.join(self.data_path, "tiny-imagenet-200")
-        if not os.path.exists(f"{path}.zip"):
-            download(self.url, self.data_path)
         if not os.path.exists(path):
+            if not os.path.exists(f"{path}.zip"):
+                download(self.url, self.data_path)
             unzip(f"{path}.zip")
 
     @property
