@@ -11,23 +11,9 @@ class CIFAR10(PyTorchDataset):
 
     @property
     def transformations(self):
-        return [
-            transforms.ToTensor(),
-            transforms.Normalize((0.4914, 0.4822, 0.4465), (0.2023, 0.1994, 0.2010))
-        ]
-
-
-class CIFAR100(PyTorchDataset):
-
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, dataset_type=torchdata.cifar.CIFAR100, **kwargs)
-
-    @property
-    def transformations(self):
-        return [
-            transforms.ToTensor(),
-            transforms.Normalize((0.5071, 0.4867, 0.4408), (0.2675, 0.2565, 0.2761))
-        ]
+        """Default transformations if nothing is provided to the scenario."""
+        return [transforms.ToTensor(),
+                transforms.Normalize((0.4914, 0.4822, 0.4465), (0.2023, 0.1994, 0.2010))]
 
 
 class MNIST(PyTorchDataset):
