@@ -97,7 +97,7 @@ def positive_backward_transfer(all_preds, all_targets, all_tasks):
     :return: a float metric between 0 and 1.
     """
     bwt = backward_transfer(all_preds, all_targets, all_tasks)
-    metric = 1 - abs(min(bwt, 0.))
+    metric = max(bwt, 0.)
     assert 0. <= metric <= 1.0, metric
     return metric
 
@@ -115,7 +115,7 @@ def remembering(all_preds, all_targets, all_tasks):
     :return: a float metric between 0 and 1.
     """
     bwt = backward_transfer(all_preds, all_targets, all_tasks)
-    metric = max(bwt, 0.)
+    metric = 1 - abs(min(bwt, 0.))
     assert 0. <= metric <= 1.0, metric
     return metric
 
@@ -229,14 +229,17 @@ def get_model_size(model):
     :return: The number of parameters.
     """
     nb_params = 0
-    # we want he number of parameter for inference
+    # store original state
+    orig_state = model.training
+    # we want the number of parameter for inference
     model.eval()
     for w in model.parameters():
         if len(w.shape) > 0:  # Tensor
             nb_params += reduce(lambda a, b: a * b, w.shape)
         else:  # Scalar
             nb_params += 1
-
+    # restore previous state
+    model.train(orig_state)
     return nb_params
 
 
