@@ -52,12 +52,16 @@ class ClassIncremental(_BaseScenario):
             if self.cl_dataset.class_order is not None:
                 self.class_order = self.cl_dataset.class_order
             else:
-                self.class_order = unique_classes
+                self.class_order = np.arange(np.max(y) + 1)
         self.class_order = list(self.class_order)
 
         if len(np.unique(self.class_order)) != len(self.class_order):
             raise ValueError(f"Invalid class order, duplicates found: {self.class_order}.")
 
+        if len(self.class_order) > len(unique_classes):
+            missing_classes = set(self.class_order) - set(unique_classes)
+            warnings.warn(f"There are some missing classes: {missing_classes}!")
+
         # Map the classes ids to their new values according to class order.
         # Aka if the user wants that the first 2 classes are 2, 7; then all
         # samples with classes 2 & 7 are resp. labeled as 0 & 1.
