@@ -6,6 +6,7 @@ import numpy as np
 
 from continuum.datasets import _ContinuumDataset
 from continuum.scenarios import _BaseScenario
+from continuum.tasks import TaskType
 
 
 class ContinualScenario(_BaseScenario):
@@ -31,7 +32,11 @@ class ContinualScenario(_BaseScenario):
         x, y, t = cl_dataset.get_data()
 
         assert t is not None, print("The t vector should be defined for this scenario")
-        assert len(x) == len(y) == len(t), print("data, label and task label vectors need to have the same length")
+
+        if cl_dataset.data_type != TaskType.H5:
+            assert len(x) == len(y) == len(t), print("data, label and task label vectors need to have the same length")
+        else:
+            assert len(y) == len(t), print("label and task label vectors need to have the same length")
 
         list_unique_tasks_ids = np.unique(t)
         self._nb_tasks = len(list_unique_tasks_ids)
@@ -46,7 +51,6 @@ class ContinualScenario(_BaseScenario):
             f"zero to num_tasks-1 \n (unique task indexes) {list_unique_tasks_ids} vs "
             f"(expected) {np.arange(self.nb_tasks)}")
 
-
-    #nothing to do in the setup function
+    # nothing to do in the setup function
     def _setup(self, nb_tasks: int) -> int:
         return nb_tasks
