@@ -2,6 +2,6 @@
 # flake8: noqa
 from continuum.tasks.task_set import TaskSet
 from continuum.tasks.base import TaskType
-from continuum.tasks.utils import split_train_val, concat
+from continuum.tasks.utils import split_train_val, concat, get_balanced_sampler
 
 __all__ = ["TaskSet", "TaskType"]
