@@ -92,3 +92,19 @@ def test_slicing_nc_no_index():
     assert (targets == np.array(classes)).all(), (targets, classes)
 
 
+@pytest.mark.parametrize("list_tasks", [
+    np.arange(10),
+    np.arange(5, 10),
+    np.arange(3, 10, 2),
+    np.arange(9, 0, -2),
+    np.arange(0, 10, 2),
+    list(np.arange(0, 10, 2)),
+    list(np.arange(5, 10))
+])
+def test_slicing_list(list_tasks):
+    train, test = gen_data()
+    dummy = InMemoryDataset(*train)
+    scenario = ClassIncremental(dummy, increment=1)
+    taskset = scenario[list_tasks]
+    targets = np.sort(np.unique(taskset._y))
+    assert len(targets) == len(list_tasks), print(f"{len(targets)} - vs - {len(list_tasks)}")
